@@ -60,24 +60,24 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-3.4.33-2.24.1.src.rpm ]
+if [ ! -r kernel-source-3.4.47-2.38.1.src.rpm ]
 then
-    wget http://download.opensuse.org/update/12.2/src/kernel-source-3.4.33-2.24.1.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/12.2/src/kernel-source-3.4.47-2.38.1.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-source-3.4.33-2.24.1.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-source-3.4.33-2.24.1.src.rpm || die "Can't install source package."
+rpm --checksig kernel-source-3.4.47-2.38.1.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-source-3.4.47-2.38.1.src.rpm || die "Can't install source package."
 
-if [ ! -r kernel-default-3.4.33-2.24.1.nosrc.rpm ]
+if [ ! -r kernel-default-3.4.47-2.38.1.nosrc.rpm ]
 then
-    wget http://download.opensuse.org/update/12.2/nosrc/kernel-default-3.4.33-2.24.1.nosrc.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/12.2/nosrc/kernel-default-3.4.47-2.38.1.nosrc.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-default-3.4.33-2.24.1.nosrc.rpm || die "Can't verify signature."
-rpm -ivh kernel-default-3.4.33-2.24.1.nosrc.rpm || die "Can't install source package."
+rpm --checksig kernel-default-3.4.47-2.38.1.nosrc.rpm || die "Can't verify signature."
+rpm -ivh kernel-default-3.4.47-2.38.1.nosrc.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20130512.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20130707.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20130512.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20130512.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20130707.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20130707.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -85,25 +85,27 @@ cp -p /usr/src/packages/SPECS/kernel-default.spec . || die "Can't copy spec file
 patch << "EOF" || die "Can't patch spec file."
 --- kernel-default.spec
 +++ kernel-default.spec
-@@ -55,10 +55,10 @@
+@@ -54,12 +54,12 @@
  %define install_vdso 0
  %endif
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
  Summary:        The Standard Kernel
- Version:        3.4.33
--Release:        2.24.1
-+Release:        2.24.1_tomoyo_1.8.3p7
  License:        GPL-2.0
  Group:          System/Kernel
+ Version:        3.4.47
+-Release:        2.38.1
++Release:        2.38.1_tomoyo_1.8.3p7
  Url:            http://www.kernel.org/
-@@ -342,6 +342,11 @@
+ BuildRequires:  coreutils
+ BuildRequires:  fdupes
+@@ -347,6 +347,11 @@
  %endif
  	%_sourcedir/series.conf .. $SYMBOLS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20130512.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20130707.tar.gz
 +patch -sp1 < patches/ccs-patch-3.4-suse-12.2.diff
 +cat config.ccs >> ../config/%cpu_arch_flavor
 +
